@@ -55,7 +55,7 @@ typedef enum
   /* These are the displayed columns */
   GPA_KEYLIST_COLUMN_IMAGE,
   GPA_KEYLIST_COLUMN_KEYTYPE,
-  GPA_KEYLIST_COLUMN_KEYID,
+  GPA_KEYLIST_COLUMN_CREATED,
   GPA_KEYLIST_COLUMN_EXPIRY,
   GPA_KEYLIST_COLUMN_OWNERTRUST,
   GPA_KEYLIST_COLUMN_VALIDITY,
@@ -64,6 +64,7 @@ typedef enum
   GPA_KEYLIST_COLUMN_KEY,
   /* These columns are used only internally for sorting */
   GPA_KEYLIST_COLUMN_HAS_SECRET,
+  GPA_KEYLIST_COLUMN_CREATED_TS,
   GPA_KEYLIST_COLUMN_EXPIRY_TS,
   GPA_KEYLIST_COLUMN_OWNERTRUST_VALUE,
   GPA_KEYLIST_COLUMN_VALIDITY_VALUE,
@@ -203,6 +204,7 @@ gpa_keylist_init (GTypeInstance *instance, void *class_ptr)
 			      G_TYPE_INT,
 			      G_TYPE_ULONG,
 			      G_TYPE_ULONG,
+			      G_TYPE_ULONG,
 			      G_TYPE_LONG);
 
   /* Setup the view.  */
@@ -422,8 +424,8 @@ gpa_keylist_next (gpgme_key_t key, gpointer data)
   GpaKeyList *list = data;
   GtkListStore *store;
   GtkTreeIter iter;
-  const gchar *keyid, *ownertrust, *validity;
-  gchar *userid, *expiry;
+  const gchar *ownertrust, *validity;
+  gchar *userid, *created, *expiry;
   gboolean has_secret;
   long int val_value;
   const char *keytype;
@@ -468,9 +470,9 @@ gpa_keylist_next (gpgme_key_t key, gpointer data)
   list->keys = g_list_append (list->keys, key);
   store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (list)));
   /* Get the column values */
-  keyid = gpa_gpgme_key_get_short_keyid (key);
   keytype = (key->protocol == GPGME_PROTOCOL_OpenPGP? "P" :
              key->protocol == GPGME_PROTOCOL_CMS? "X" : "?");
+  created = gpa_creation_date_string (key->subkeys->timestamp);
   expiry = gpa_expiry_date_string (key->subkeys->expires);
   ownertrust = gpa_key_ownertrust_string (key);
   validity = gpa_key_validity_string (key);
@@ -502,17 +504,20 @@ gpa_keylist_next (gpgme_key_t key, gpointer data)
 
   gtk_list_store_set (store, &iter,
 		      GPA_KEYLIST_COLUMN_KEYTYPE, keytype,
-		      GPA_KEYLIST_COLUMN_KEYID, keyid,
+		      GPA_KEYLIST_COLUMN_CREATED, created,
 		      GPA_KEYLIST_COLUMN_EXPIRY, expiry,
 		      GPA_KEYLIST_COLUMN_OWNERTRUST, ownertrust,
 		      GPA_KEYLIST_COLUMN_VALIDITY, validity,
 		      GPA_KEYLIST_COLUMN_USERID, userid,
 		      GPA_KEYLIST_COLUMN_KEY, key,
 		      GPA_KEYLIST_COLUMN_HAS_SECRET, has_secret,
+		      GPA_KEYLIST_COLUMN_CREATED_TS, key->subkeys->timestamp,
+
 		      /* Set "no expiration" to a large value for sorting */
 		      GPA_KEYLIST_COLUMN_EXPIRY_TS,
 		      key->subkeys->expires ?
 		      key->subkeys->expires : G_MAXULONG,
+
 		      GPA_KEYLIST_COLUMN_OWNERTRUST_VALUE,
 		      key->owner_trust,
 		      /* Set revoked and expired keys to "never trust"
@@ -524,6 +529,7 @@ gpa_keylist_next (gpgme_key_t key, gpointer data)
 		      -1);
   /* Clean up */
   g_free (userid);
+  g_free (created);
   g_free (expiry);
 }
 
@@ -557,21 +563,17 @@ search_keylist_function (GtkTreeModel *model, gint column,
                          gpointer search_data)
 {
   gboolean result = TRUE;
-  gchar *key_id, *user_id;
+  gchar *user_id;
   gint search_len;
 
   gtk_tree_model_get (model, iter,
-                      GPA_KEYLIST_COLUMN_KEYID, &key_id,
                       GPA_KEYLIST_COLUMN_USERID, &user_id, -1);
 
   search_len = strlen (key_to_search_for);
 
-  if (!g_ascii_strncasecmp (key_id, key_to_search_for, search_len))
-    result=FALSE;
   if (!g_ascii_strncasecmp (user_id, key_to_search_for, search_len))
     result=FALSE;
 
-  g_free (key_id);
   g_free (user_id);
 
   return result;
@@ -615,15 +617,15 @@ setup_columns (GpaKeyList *keylist, gboolean detailed)
 
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes
-    (NULL, renderer, "text", GPA_KEYLIST_COLUMN_KEYID, NULL);
+    (NULL, renderer, "text", GPA_KEYLIST_COLUMN_CREATED, NULL);
   gpa_set_column_title
-    (column, _("Key ID"),
-     _("The key ID is a short number to identify a certificate."));
+    (column, _("Created"),
+     _("The Creation Date is the date the certificate was created."));
   gtk_tree_view_append_column (GTK_TREE_VIEW (keylist), column);
-  gtk_tree_view_column_set_sort_column_id (column, GPA_KEYLIST_COLUMN_KEYID);
+  gtk_tree_view_column_set_sort_column_id
+    (column, GPA_KEYLIST_COLUMN_CREATED_TS);
   gtk_tree_view_column_set_sort_indicator (column, TRUE);
 
-
   if (detailed)
     {
       renderer = gtk_cell_renderer_text_new ();
@@ -799,9 +801,11 @@ gpa_keylist_has_single_secret_selection (GpaKeyList *keylist)
 
 
 /* Return a GList of selected keys. The caller must not dereference
-   the keys as they belong to the caller.  */
+   the keys as they belong to the caller.  Unless PROTOCOL is
+   GPGME_PROTOCOL_UNKNOWN, only keys matching thhe requested protocol
+   are returned.  */
 GList *
-gpa_keylist_get_selected_keys (GpaKeyList * keylist)
+gpa_keylist_get_selected_keys (GpaKeyList * keylist, gpgme_protocol_t protocol)
 {
   GtkTreeSelection *selection =
     gtk_tree_view_get_selection (GTK_TREE_VIEW (keylist));
@@ -823,7 +827,10 @@ gpa_keylist_get_selected_keys (GpaKeyList * keylist)
       key = g_value_get_pointer (&value);
       g_value_unset(&value);
 
-      keys = g_list_append (keys, key);
+      /* Fixme: Why don't we ref KEY? */
+      if (key && (protocol == GPGME_PROTOCOL_UNKNOWN
+                  || protocol == key->protocol))
+        keys = g_list_append (keys, key);
     }
 
   g_list_foreach (list, (GFunc) gtk_tree_path_free, NULL);
